@@ -21,7 +21,7 @@ import jinjafx, os, io, sys, socket, signal, threading, yaml, json, base64, time
 import re, argparse, zipfile, hashlib, traceback, glob, hmac, uuid, struct, binascii, gzip, requests
 import cmarkgfm, emoji
 
-__version__ = '22.5.3'
+__version__ = '22.5.4'
 
 lock = threading.RLock()
 base = os.path.abspath(os.path.dirname(__file__))
@@ -350,6 +350,9 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                     output = emoji.emojize(output, language='alias').encode('ascii', 'xmlcharrefreplace').decode('utf-8')
                     output = head + '<div class="markdown-body">\n' + output + '</div>\n'
 
+                  elif oformat == 'html':
+                    output = output.encode('ascii', 'xmlcharrefreplace').decode('utf-8')
+
                   jsr['outputs'].update({ o: base64.b64encode(output.encode('utf-8')).decode('utf-8') })
                   if o != '_stderr_':
                     ocount += 1
